summaryrefslogtreecommitdiff
path: root/src/plugins/html/DemoOutput.hpp
diff options
context:
space:
mode:
authorBenjamin Paassen <bpaassen@techfak.uni-bielefeld.de>2015-01-09 17:00:53 +0100
committerBenjamin Paassen <bpaassen@techfak.uni-bielefeld.de>2015-01-09 17:00:53 +0100
commitf37d3cd42eb18433445c2e259cd71a1b2bd67be0 (patch)
treec4371b1b4e3f578a6d20dc76dd74fb85d6fb901a /src/plugins/html/DemoOutput.hpp
parent58fed7b74357b82ba55558f91ae13123dc2380eb (diff)
added non-pretty output of XML serialization, changed DemoOutput accordingly and changed DemoOutputTest to have some kind of automatic inspection instead of visual inspection.
Diffstat (limited to 'src/plugins/html/DemoOutput.hpp')
-rw-r--r--src/plugins/html/DemoOutput.hpp11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/plugins/html/DemoOutput.hpp b/src/plugins/html/DemoOutput.hpp
index 07d758b..b755aac 100644
--- a/src/plugins/html/DemoOutput.hpp
+++ b/src/plugins/html/DemoOutput.hpp
@@ -83,11 +83,14 @@ public:
* Therefore this is not an adequate model of our algorithms but only a
* Demo.
*
* @param doc is a Document using concepts of the book, headings, emphasis
* and lists domains but no other.
* @param out is the output stream the data shall be written to.
*/
- void writeHTML(Handle<model::Document> doc, std::ostream &out);
+ void writeHTML(Handle<model::Document> doc, std::ostream &out,
+ bool pretty = true);
};
}
}
@@ -83,11 +83,14 @@ public:
* Demo.
*
- * @param doc is a Document using concepts of the book, headings, emphasis
- * and lists domains but no other.
- * @param out is the output stream the data shall be written to.
+ * @param doc is a Document using concepts of the book, headings,
+ * emphasis and lists domains but no other.
+ * @param out is the output stream the data shall be written to.
+ * @param pretty is a flag that manipulates whether newlines and tabs are
+ * used.
*/